@@ -13,7 +13,8 @@ def exist():
 def install():
     sys = platform.system()
     if sys=="Darwin":
-        subprocess.call(["sudo","-S","installer","-verbose","-pkg",os.path.dirname(__file__)+"/driver/ch34x_install.pkg","-target","/"])
+        subprocess.call(["/usr/bin/open",os.path.dirname(__file__)+"/driver/ch34x_install.pkg"])
+        #["installer","-pkg",os.path.dirname(__file__)+"/driver/ch34x_install.pkg","-target","/"])
     elif sys=="Windows":
         subprocess.call([os.path.dirname(__file__)+"/driver/ch34x_install.exe"])
     return
\ No newline at end of file
